AGW Logo

svn SVN Revision 68439 For customtreectrl

This file contains the SVN revision history for customtreectrl, at revision 68439.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 11-Dec-2009 11:51:15 UTC
  • Committer: AG
  • File Size: 263602 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

CustomTreeCtrl: fix a silly mistake on RecurseOnChildren(): when there are no more children, GetNextChild() returns None, which does not have an IsOK() method so throws an AttributeError. Thanks to Jill Holliday for the bug report and the patch.


svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/customtreectrl.py     2011/07/27 17:17:15     68439
@@ -3,7 +3,7 @@
# Inspired By And Heavily Based On wxGenericTreeCtrl.
#
# Andrea Gavana, @ 17 May 2006
# Latest Revision: 21 Jun 2011, 22.00 GMT
#
#
# TODO List
@@ -212,7 +212,7 @@

CustomTreeCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 21 Jun 2011, 22.00 GMT
+Latest Revision: Andrea Gavana @ 27 Jul 2011, 19.00 GMT

Version 2.4

@@ -7513,8 +7513,9 @@
"""

child, cookie = self.GetFirstChild(item)
+        lastheight = 0

-        while child.IsOk():
+        while child:

rect = self.GetBoundingRect(child, True)
Tree
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 17 May 2006
-# Latest Revision: 21 Jun 2011, 22.00 GMT
+# Latest Revision: 27 Jul 2011, 19.00 GMT
#
#